# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2017-11-05 21:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('useragents', '0008_auto_20171104_1731'),
    ]

    operations = [
        migrations.AddField(
            model_name='visit',
            name='content_type',
            field=models.CharField(blank=True, max_length=256),
        ),
        migrations.AddField(
            model_name='visit',
            name='encoding',
            field=models.CharField(blank=True, max_length=265),
        ),
        migrations.AddField(
            model_name='visit',
            name='method',
            field=models.CharField(blank=True, max_length=10),
        ),
    ]
