# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2017-11-04 19:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('useragents', '0004_auto_20171104_1239'),
    ]

    operations = [
        migrations.RenameField(
            model_name='ip',
            old_name='date_created',
            new_name='created',
        ),
        migrations.RenameField(
            model_name='path',
            old_name='date_created',
            new_name='created',
        ),
        migrations.RenameField(
            model_name='useragent',
            old_name='date_created',
            new_name='created',
        ),
        migrations.RenameField(
            model_name='visit',
            old_name='date_created',
            new_name='created',
        ),
        migrations.AddField(
            model_name='ip',
            name='modified',
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.AddField(
            model_name='path',
            name='modified',
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.AddField(
            model_name='useragent',
            name='modified',
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.AddField(
            model_name='visit',
            name='modified',
            field=models.DateTimeField(auto_now=True),
        ),
    ]
