# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2017-11-05 00:31
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('useragents', '0007_auto_20171104_1327'),
    ]

    operations = [
        migrations.AlterField(
            model_name='visit',
            name='path',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='useragents.Path'),
        ),
    ]
