# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2017-11-04 20:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('useragents', '0005_auto_20171104_1248'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='visit',
            name='modified',
        ),
        migrations.AlterField(
            model_name='ip',
            name='visits',
            field=models.PositiveIntegerField(blank=True, default=0, unique=True),
        ),
        migrations.AlterField(
            model_name='path',
            name='visits',
            field=models.PositiveIntegerField(blank=True, default=0, unique=True),
        ),
        migrations.AlterField(
            model_name='useragent',
            name='visits',
            field=models.PositiveIntegerField(blank=True, default=0, unique=True),
        ),
    ]
